Function git_quickfix::get_default_branch [−][src]
pub fn get_default_branch(repo: &Repository) -> Result<String, Report>Expand description
A hacky way to resolve the default branch name on the ‘origin’ remote.
pub fn get_default_branch(repo: &Repository) -> Result<String, Report>A hacky way to resolve the default branch name on the ‘origin’ remote.